/* SerializablePropertyEnumTest.c generated by valac 0.34.6, the Vala compiler
 * generated from SerializablePropertyEnumTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST (serializable_property_enum_test_get_type ())
#define SERIALIZABLE_PROPERTY_ENUM_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST, SerializablePropertyEnumTest))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST, SerializablePropertyEnumTestClass))
#define IS_SERIALIZABLE_PROPERTY_ENUM_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST))
#define IS_SERIALIZABLE_PROPERTY_ENUM_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST, SerializablePropertyEnumTestClass))

typedef struct _SerializablePropertyEnumTest SerializablePropertyEnumTest;
typedef struct _SerializablePropertyEnumTestClass SerializablePropertyEnumTestClass;
typedef struct _SerializablePropertyEnumTestPrivate SerializablePropertyEnumTestPrivate;

#define SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES (serializable_property_enum_test_enumeration_values_get_type ())
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValues))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValuesClass))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_IS_ENUMERATION_VALUES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_IS_ENUMERATION_VALUES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValuesClass))

typedef struct _SerializablePropertyEnumTestEnumerationValues SerializablePropertyEnumTestEnumerationValues;
typedef struct _SerializablePropertyEnumTestEnumerationValuesClass SerializablePropertyEnumTestEnumerationValuesClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_TYPE_VALUES (serializable_property_enum_test_enum_values_get_type ())

#define SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM (serializable_property_enum_test_enum_get_type ())
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, SerializablePropertyEnumTestEnum))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, SerializablePropertyEnumTestEnumClass))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_IS_ENUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_IS_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, SerializablePropertyEnumTestEnumClass))

typedef struct _SerializablePropertyEnumTestEnum SerializablePropertyEnumTestEnum;
typedef struct _SerializablePropertyEnumTestEnumClass SerializablePropertyEnumTestEnumClass;
typedef struct _SerializablePropertyEnumTestEnumPrivate SerializablePropertyEnumTestEnumPrivate;
typedef struct _SerializablePropertyEnumTestEnumerationValuesPrivate SerializablePropertyEnumTestEnumerationValuesPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializablePropertyEnumTest {
	GXmlTest parent_instance;
	SerializablePropertyEnumTestPrivate * priv;
};

struct _SerializablePropertyEnumTestClass {
	GXmlTestClass parent_class;
};

typedef enum  {
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_AP,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_EXTENSION
} SerializablePropertyEnumTestEnumValues;

struct _SerializablePropertyEnumTestEnum {
	GXmlSerializableEnum parent_instance;
	SerializablePropertyEnumTestEnumPrivate * priv;
};

struct _SerializablePropertyEnumTestEnumClass {
	GXmlSerializableEnumClass parent_class;
};

struct _SerializablePropertyEnumTestEnumerationValues {
	GXmlSerializableObjectModel parent_instance;
	SerializablePropertyEnumTestEnumerationValuesPrivate * priv;
};

struct _SerializablePropertyEnumTestEnumerationValuesClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializablePropertyEnumTestEnumerationValuesPrivate {
	SerializablePropertyEnumTestEnum* _values;
	SerializablePropertyEnumTestEnum* _optional_values;
	gint _integer;
	gchar* _name;
};


static gpointer serializable_property_enum_test_parent_class = NULL;
static gpointer serializable_property_enum_test_enum_parent_class = NULL;
static gpointer serializable_property_enum_test_enumeration_values_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_property_enum_test_get_type (void) G_GNUC_CONST;
enum  {
	SERIALIZABLE_PROPERTY_ENUM_TEST_DUMMY_PROPERTY
};
void serializable_property_enum_test_add_tests (void);
static void __lambda154_ (void);
GType serializable_property_enum_test_enumeration_values_get_type (void) G_GNUC_CONST;
SerializablePropertyEnumTestEnumerationValues* serializable_property_enum_test_enumeration_values_new (void);
SerializablePropertyEnumTestEnumerationValues* serializable_property_enum_test_enumeration_values_construct (GType object_type);
static void ___lambda154__gtest_func (void);
static void __lambda155_ (void);
GType serializable_property_enum_test_enum_values_get_type (void) G_GNUC_CONST;
SerializablePropertyEnumTestEnum* serializable_property_enum_test_enum_new (void);
SerializablePropertyEnumTestEnum* serializable_property_enum_test_enum_construct (GType object_type);
GType serializable_property_enum_test_enum_get_type (void) G_GNUC_CONST;
void serializable_property_enum_test_enumeration_values_set_values (SerializablePropertyEnumTestEnumerationValues* self, SerializablePropertyEnumTestEnum* value);
SerializablePropertyEnumTestEnum* serializable_property_enum_test_enumeration_values_get_values (SerializablePropertyEnumTestEnumerationValues* self);
SerializablePropertyEnumTestEnumValues serializable_property_enum_test_enum_get_value (SerializablePropertyEnumTestEnum* self, GError** error);
void serializable_property_enum_test_enum_set_value (SerializablePropertyEnumTestEnum* self, SerializablePropertyEnumTestEnumValues val, GError** error);
void serializable_property_enum_test_enum_set_string (SerializablePropertyEnumTestEnum* self, const gchar* str, GError** error);
static void ___lambda155__gtest_func (void);
static void __lambda156_ (void);
static void ___lambda156__gtest_func (void);
static void __lambda157_ (void);
SerializablePropertyEnumTestEnum* serializable_property_enum_test_enumeration_values_get_optional_values (SerializablePropertyEnumTestEnumerationValues* self);
static void ___lambda157__gtest_func (void);
SerializablePropertyEnumTest* serializable_property_enum_test_new (void);
SerializablePropertyEnumTest* serializable_property_enum_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
enum  {
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_DUMMY_PROPERTY
};
static GObject * serializable_property_enum_test_enum_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValuesPrivate))
enum  {
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_DUMMY_PROPERTY,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME
};
static gchar* serializable_property_enum_test_enumeration_values_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_property_enum_test_enumeration_values_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_property_enum_test_enumeration_values_real_property_use_nick (GXmlSerializableObjectModel* base);
void serializable_property_enum_test_enumeration_values_set_optional_values (SerializablePropertyEnumTestEnumerationValues* self, SerializablePropertyEnumTestEnum* value);
gint serializable_property_enum_test_enumeration_values_get_integer (SerializablePropertyEnumTestEnumerationValues* self);
void serializable_property_enum_test_enumeration_values_set_integer (SerializablePropertyEnumTestEnumerationValues* self, gint value);
const gchar* serializable_property_enum_test_enumeration_values_get_name (SerializablePropertyEnumTestEnumerationValues* self);
void serializable_property_enum_test_enumeration_values_set_name (SerializablePropertyEnumTestEnumerationValues* self, const gchar* value);
static void serializable_property_enum_test_enumeration_values_finalize (GObject* obj);
static void _vala_serializable_property_enum_test_enumeration_values_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_serializable_property_enum_test_enumeration_values_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 195 "SerializablePropertyEnumTest.c"
}


static void __lambda154_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyEnumTestEnumerationValues* e = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp0_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlElement* _tmp10_ = NULL;
		GXmlNode* ee1 = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* s = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* i = NULL;
		GXmlNode* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp0_ = serializable_property_enum_test_enumeration_values_new ();
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		e = _tmp0_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		doc = _tmp1_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) e, (GXmlNode*) doc, &_inner_error_);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp3_ = _tmp2_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp3_);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 245 "SerializablePropertyEnumTest.c"
			goto __catch27_g_error;
		}
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp5_ = _tmp4_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp6_ = g_strconcat ("XML:\n", _tmp5_, NULL);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp7_ = _tmp6_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp7_);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp7_);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp5_);
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp9_ = _tmp8_;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp9_) : NULL;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (_tmp10_ == NULL) {
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp9_);
#line 272 "SerializablePropertyEnumTest.c"
		}
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		element = _tmp10_;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp11_ = gxml_element_get_attr (element, "values");
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		ee1 = _tmp11_;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (ee1 == NULL, "ee1 == null");
#line 67 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp12_ = gxml_element_get_attr (element, "name");
#line 67 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		s = _tmp12_;
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp13_ = gxml_element_get_attr (element, "integer");
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		i = _tmp13_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp14_ = gxml_node_get_value (i);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp15_ = _tmp14_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp16_ = _tmp15_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "0") == 0, "i.value == \"0\"");
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp16_);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (i);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (s);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee1);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (doc);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (e);
#line 314 "SerializablePropertyEnumTest.c"
	}
	goto __finally27;
	__catch27_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		e = _inner_error_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_inner_error_ = NULL;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp17_ = e->message;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp18_ = string_to_string (_tmp17_);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp19_ = g_strconcat ("ERROR: ", _tmp18_, NULL);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp20_ = _tmp19_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp20_);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp20_);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_assert_not_reached ();
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_error_free0 (e);
#line 344 "SerializablePropertyEnumTest.c"
	}
	__finally27:
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_clear_error (&_inner_error_);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		return;
#line 355 "SerializablePropertyEnumTest.c"
	}
}


static void ___lambda154__gtest_func (void) {
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	__lambda154_ ();
#line 363 "SerializablePropertyEnumTest.c"
}


static void __lambda155_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyEnumTestEnumerationValues* e = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp0_ = NULL;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlElement* element1 = NULL;
		GXmlGDocument* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlElement* _tmp14_ = NULL;
		GXmlNode* ee1 = NULL;
		GXmlElement* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlNode* _tmp17_ = NULL;
		GXmlNode* s1 = NULL;
		GXmlElement* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		GXmlNode* i1 = NULL;
		GXmlElement* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		SerializablePropertyEnumTestEnumValues v = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp27_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp28_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp29_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp39_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp40_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp41_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp42_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp43_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp44_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp45_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp46_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp47_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp48_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp54_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp55_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp59_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp60_ = NULL;
		GXmlGDocument* _tmp61_ = NULL;
		GXmlNode* _tmp62_ = NULL;
		GXmlNode* _tmp63_ = NULL;
		GXmlGDocument* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp69_ = NULL;
		GXmlNode* _tmp70_ = NULL;
		GXmlNode* _tmp71_ = NULL;
		GXmlElement* _tmp72_ = NULL;
		GXmlNode* ee2 = NULL;
		GXmlElement* _tmp73_ = NULL;
		GXmlNode* _tmp74_ = NULL;
		GXmlNode* _tmp75_ = NULL;
		GXmlNode* _tmp76_ = NULL;
		gchar* _tmp77_ = NULL;
		gchar* _tmp78_ = NULL;
		gchar* _tmp79_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp80_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp81_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp82_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp83_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp84_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp85_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp86_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp87_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp88_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp89_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp90_ = NULL;
		gchar* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		gchar* _tmp93_ = NULL;
		gchar* _tmp94_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp95_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp96_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp97_ = NULL;
		gchar* _tmp98_ = NULL;
		gchar* _tmp99_ = NULL;
		GXmlGDocument* d3 = NULL;
		GXmlGDocument* _tmp100_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp101_ = NULL;
		GXmlGDocument* _tmp102_ = NULL;
		GXmlNode* _tmp103_ = NULL;
		GXmlNode* _tmp104_ = NULL;
		GXmlGDocument* _tmp105_ = NULL;
		gchar* _tmp106_ = NULL;
		gchar* _tmp107_ = NULL;
		gchar* _tmp108_ = NULL;
		gchar* _tmp109_ = NULL;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp110_ = NULL;
		GXmlNode* _tmp111_ = NULL;
		GXmlNode* _tmp112_ = NULL;
		GXmlElement* _tmp113_ = NULL;
		GXmlNode* ee3 = NULL;
		GXmlElement* _tmp114_ = NULL;
		GXmlNode* _tmp115_ = NULL;
		GXmlNode* _tmp116_ = NULL;
		GXmlNode* _tmp117_ = NULL;
		gchar* _tmp118_ = NULL;
		gchar* _tmp119_ = NULL;
		gchar* _tmp120_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp121_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp122_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp123_ = NULL;
		GXmlGDocument* d4 = NULL;
		GXmlGDocument* _tmp124_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp125_ = NULL;
		GXmlGDocument* _tmp126_ = NULL;
		GXmlNode* _tmp127_ = NULL;
		GXmlNode* _tmp128_ = NULL;
		GXmlGDocument* _tmp129_ = NULL;
		gchar* _tmp130_ = NULL;
		gchar* _tmp131_ = NULL;
		gchar* _tmp132_ = NULL;
		gchar* _tmp133_ = NULL;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp134_ = NULL;
		GXmlNode* _tmp135_ = NULL;
		GXmlNode* _tmp136_ = NULL;
		GXmlElement* _tmp137_ = NULL;
		GXmlNode* ee4 = NULL;
		GXmlNode* _tmp138_ = NULL;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp0_ = serializable_property_enum_test_enumeration_values_new ();
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		e = _tmp0_;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		doc1 = _tmp1_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp2_ = e;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp3_ = doc1;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp5_ = _tmp4_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp5_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 540 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp6_ = doc1;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) _tmp6_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp8_ = _tmp7_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp9_ = g_strconcat ("XML1:\n", _tmp8_, NULL);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp10_ = _tmp9_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp10_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp10_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp8_);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp11_ = doc1;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) _tmp11_);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp13_ = _tmp12_;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (_tmp14_ == NULL) {
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp13_);
#line 571 "SerializablePropertyEnumTest.c"
		}
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		element1 = _tmp14_;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp15_ = element1;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp16_ = gxml_element_get_attr (_tmp15_, "values");
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		ee1 = _tmp16_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp17_ = ee1;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp17_ == NULL, "ee1 == null");
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp18_ = element1;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "name");
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		s1 = _tmp19_;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp20_ = s1;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp20_ == NULL, "s1 == null");
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp21_ = element1;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp22_ = gxml_element_get_attr (_tmp21_, "integer");
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		i1 = _tmp22_;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp23_ = i1;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp24_ = gxml_node_get_value (_tmp23_);
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp25_ = _tmp24_;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp26_ = _tmp25_;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "0") == 0, "i1.value == \"0\"");
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp26_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		v = SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp27_ = e;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp28_ = serializable_property_enum_test_enum_new ();
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp29_ = _tmp28_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_values (_tmp27_, _tmp29_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp29_);
#line 625 "SerializablePropertyEnumTest.c"
		{
			SerializablePropertyEnumTestEnumValues _tmp30_ = 0;
			SerializablePropertyEnumTestEnumerationValues* _tmp31_ = NULL;
			SerializablePropertyEnumTestEnum* _tmp32_ = NULL;
			SerializablePropertyEnumTestEnum* _tmp33_ = NULL;
			SerializablePropertyEnumTestEnumValues _tmp34_ = 0;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp31_ = e;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp32_ = serializable_property_enum_test_enumeration_values_get_values (_tmp31_);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp33_ = _tmp32_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp34_ = serializable_property_enum_test_enum_get_value (_tmp33_, &_inner_error_);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp30_ = _tmp34_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 644 "SerializablePropertyEnumTest.c"
				goto __catch29_g_error;
			}
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			v = _tmp30_;
#line 649 "SerializablePropertyEnumTest.c"
		}
		goto __finally29;
		__catch29_g_error:
		{
			GError* e = NULL;
			GError* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			gchar* _tmp37_ = NULL;
			gchar* _tmp38_ = NULL;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			e = _inner_error_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_inner_error_ = NULL;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp35_ = e;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp36_ = _tmp35_->message;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp37_ = g_strconcat ("Error cough correctly: ", _tmp36_, NULL);
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_tmp38_ = _tmp37_;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			g_test_message ("%s", _tmp38_);
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_free0 (_tmp38_);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_error_free0 (e);
#line 677 "SerializablePropertyEnumTest.c"
		}
		__finally29:
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 694 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp39_ = e;
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp40_ = serializable_property_enum_test_enumeration_values_get_values (_tmp39_);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp41_ = _tmp40_;
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_value (_tmp41_, SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE, &_inner_error_);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 719 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp43_ = e;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp44_ = serializable_property_enum_test_enumeration_values_get_values (_tmp43_);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp45_ = _tmp44_;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp46_ = serializable_property_enum_test_enum_get_value (_tmp45_, &_inner_error_);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp42_ = _tmp46_;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 746 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp42_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE, "e.values.get_value () == Enum.Values.SER_THREE");
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp47_ = e;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp48_ = serializable_property_enum_test_enumeration_values_get_values (_tmp47_);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp49_ = _tmp48_;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp50_ = gxml_serializable_enum_to_string ((GXmlSerializableEnum*) _tmp49_);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp51_ = _tmp50_;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp52_ = g_strconcat ("Actual value= ", _tmp51_, NULL);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp53_ = _tmp52_;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp53_);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp53_);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp51_);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp54_ = e;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp55_ = serializable_property_enum_test_enumeration_values_get_values (_tmp54_);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp56_ = _tmp55_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp57_ = gxml_serializable_enum_to_string ((GXmlSerializableEnum*) _tmp56_);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp58_ = _tmp57_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "SerThree") == 0, "e.values.to_string () == \"SerThree\"");
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp58_);
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp59_ = gxml_gdocument_new ();
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		d2 = _tmp59_;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp60_ = e;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp61_ = d2;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp62_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp60_, (GXmlNode*) _tmp61_, &_inner_error_);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp63_ = _tmp62_;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp63_);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 815 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp64_ = d2;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp65_ = gxml_gnode_to_string ((GXmlGNode*) _tmp64_);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp66_ = _tmp65_;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp67_ = g_strconcat ("XML2:\n", _tmp66_, NULL);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp68_ = _tmp67_;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp68_);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp68_);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp66_);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp69_ = d2;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp70_ = gxml_document_get_root ((GXmlDocument*) _tmp69_);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp71_ = _tmp70_;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp72_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp71_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp71_) : NULL;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (_tmp72_ == NULL) {
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp71_);
#line 846 "SerializablePropertyEnumTest.c"
		}
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		element2 = _tmp72_;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp73_ = element2;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp74_ = gxml_element_get_attr (_tmp73_, "values");
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		ee2 = _tmp74_;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp75_ = ee2;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp75_ != NULL, "ee2 != null");
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp76_ = ee2;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp77_ = gxml_node_get_value (_tmp76_);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp78_ = _tmp77_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp79_ = _tmp78_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp79_, "SerThree") == 0, "ee2.value == \"SerThree\"");
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp79_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp80_ = e;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp81_ = serializable_property_enum_test_enumeration_values_get_values (_tmp80_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp82_ = _tmp81_;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_value (_tmp82_, SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO, &_inner_error_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 900 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp84_ = e;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp85_ = serializable_property_enum_test_enumeration_values_get_values (_tmp84_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp86_ = _tmp85_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp87_ = serializable_property_enum_test_enum_get_value (_tmp86_, &_inner_error_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp83_ = _tmp87_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 933 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp83_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO, "e.values.get_value () == Enum.Values.SER_TWO");
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp88_ = e;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp89_ = serializable_property_enum_test_enumeration_values_get_values (_tmp88_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp90_ = _tmp89_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp91_ = gxml_serializable_enum_to_string ((GXmlSerializableEnum*) _tmp90_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp92_ = _tmp91_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp93_ = g_strconcat ("Actual value= ", _tmp92_, NULL);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp94_ = _tmp93_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp94_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp94_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp92_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp95_ = e;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp96_ = serializable_property_enum_test_enumeration_values_get_values (_tmp95_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp97_ = _tmp96_;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp98_ = gxml_serializable_enum_to_string ((GXmlSerializableEnum*) _tmp97_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp99_ = _tmp98_;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp99_, "SerTwo") == 0, "e.values.to_string () == \"SerTwo\"");
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp99_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp100_ = gxml_gdocument_new ();
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		d3 = _tmp100_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp101_ = e;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp102_ = d3;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp103_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp101_, (GXmlNode*) _tmp102_, &_inner_error_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp104_ = _tmp103_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp104_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1008 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp105_ = d3;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp106_ = gxml_gnode_to_string ((GXmlGNode*) _tmp105_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp107_ = _tmp106_;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp108_ = g_strconcat ("XML3:\n", _tmp107_, NULL);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp109_ = _tmp108_;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp109_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp109_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp107_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp110_ = d3;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp111_ = gxml_document_get_root ((GXmlDocument*) _tmp110_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp112_ = _tmp111_;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp113_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp112_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp112_) : NULL;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (_tmp113_ == NULL) {
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp112_);
#line 1039 "SerializablePropertyEnumTest.c"
		}
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		element3 = _tmp113_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp114_ = element3;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp115_ = gxml_element_get_attr (_tmp114_, "values");
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		ee3 = _tmp115_;
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp116_ = ee3;
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp116_ != NULL, "ee3 != null");
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp117_ = ee3;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp118_ = gxml_node_get_value (_tmp117_);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp119_ = _tmp118_;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp120_ = _tmp119_;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp120_, "SerTwo") == 0, "ee3.value == \"SerTwo\"");
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp120_);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp121_ = e;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp122_ = serializable_property_enum_test_enumeration_values_get_values (_tmp121_);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp123_ = _tmp122_;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_string (_tmp123_, NULL, &_inner_error_);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee3);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element3);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1099 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp124_ = gxml_gdocument_new ();
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		d4 = _tmp124_;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp125_ = e;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp126_ = d4;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp127_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp125_, (GXmlNode*) _tmp126_, &_inner_error_);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp128_ = _tmp127_;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp128_);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d4);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee3);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element3);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1144 "SerializablePropertyEnumTest.c"
			goto __catch28_g_error;
		}
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp129_ = d4;
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp130_ = gxml_gnode_to_string ((GXmlGNode*) _tmp129_);
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp131_ = _tmp130_;
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp132_ = g_strconcat ("XML4:\n", _tmp131_, NULL);
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp133_ = _tmp132_;
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp133_);
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp133_);
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp131_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp134_ = d4;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp135_ = gxml_document_get_root ((GXmlDocument*) _tmp134_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp136_ = _tmp135_;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp137_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp136_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp136_) : NULL;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (_tmp137_ == NULL) {
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp136_);
#line 1175 "SerializablePropertyEnumTest.c"
		}
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		element4 = _tmp137_;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp138_ = gxml_element_get_attr (element4, "values");
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		ee4 = _tmp138_;
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (ee4 == NULL, "ee4 == null");
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee4);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element4);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d4);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee3);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element3);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d3);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee2);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element2);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d2);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (i1);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (s1);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee1);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element1);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (doc1);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (e);
#line 1215 "SerializablePropertyEnumTest.c"
	}
	goto __finally28;
	__catch28_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp139_ = NULL;
		const gchar* _tmp140_ = NULL;
		gchar* _tmp141_ = NULL;
		gchar* _tmp142_ = NULL;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		e = _inner_error_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_inner_error_ = NULL;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp139_ = e->message;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp140_ = string_to_string (_tmp139_);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp141_ = g_strconcat ("ERROR: ", _tmp140_, NULL);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp142_ = _tmp141_;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp142_);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp142_);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_assert_not_reached ();
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_error_free0 (e);
#line 1245 "SerializablePropertyEnumTest.c"
	}
	__finally28:
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_clear_error (&_inner_error_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		return;
#line 1256 "SerializablePropertyEnumTest.c"
	}
}


static void ___lambda155__gtest_func (void) {
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	__lambda155_ ();
#line 1264 "SerializablePropertyEnumTest.c"
}


static void __lambda156_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyEnumTestEnumerationValues* e = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp0_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp1_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp2_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp3_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp4_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp5_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp6_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp7_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp8_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp9_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp10_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp11_ = 0;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp0_ = serializable_property_enum_test_enumeration_values_new ();
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		e = _tmp0_;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp1_ = e;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp2_ = serializable_property_enum_test_enum_new ();
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp3_ = _tmp2_;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_values (_tmp1_, _tmp3_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp3_);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp4_ = e;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp5_ = serializable_property_enum_test_enumeration_values_get_values (_tmp4_);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp6_ = _tmp5_;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_string (_tmp6_, "SERONE", &_inner_error_);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1310 "SerializablePropertyEnumTest.c"
			goto __catch30_g_error;
		}
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp8_ = e;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp9_ = serializable_property_enum_test_enumeration_values_get_values (_tmp8_);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp10_ = _tmp9_;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp11_ = serializable_property_enum_test_enum_get_value (_tmp10_, &_inner_error_);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp7_ = _tmp11_;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1327 "SerializablePropertyEnumTest.c"
			goto __catch30_g_error;
		}
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp7_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE, "e.values.get_value () == Enum.Values.SER_ONE");
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (e);
#line 1334 "SerializablePropertyEnumTest.c"
	}
	goto __finally30;
	__catch30_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		e = _inner_error_;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_inner_error_ = NULL;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp12_ = e->message;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp13_ = string_to_string (_tmp12_);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp14_ = g_strconcat ("ERROR: ", _tmp13_, NULL);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp15_ = _tmp14_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp15_);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp15_);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_assert_not_reached ();
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_error_free0 (e);
#line 1364 "SerializablePropertyEnumTest.c"
	}
	__finally30:
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_clear_error (&_inner_error_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		return;
#line 1375 "SerializablePropertyEnumTest.c"
	}
}


static void ___lambda156__gtest_func (void) {
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	__lambda156_ ();
#line 1383 "SerializablePropertyEnumTest.c"
}


static void __lambda157_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyEnumTestEnumerationValues* e = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp0_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp1_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp2_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp3_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp4_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp5_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp6_ = NULL;
		GXmlGDocument* d1 = NULL;
		GXmlGDocument* _tmp7_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp8_ = NULL;
		GXmlGDocument* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlGDocument* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp17_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp18_ = NULL;
		GXmlGDocument* _tmp19_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp20_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp21_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp22_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp23_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp24_ = 0;
		GXmlGDocument* d3 = NULL;
		GXmlGDocument* _tmp25_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp26_ = NULL;
		GXmlGDocument* _tmp27_ = NULL;
		GXmlNode* _tmp28_ = NULL;
		GXmlNode* _tmp29_ = NULL;
		GXmlGDocument* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		GXmlGDocument* d4 = NULL;
		GXmlGDocument* _tmp35_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp36_ = NULL;
		GXmlGDocument* _tmp37_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp38_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp39_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp40_ = NULL;
		SerializablePropertyEnumTestEnum* _tmp41_ = NULL;
		SerializablePropertyEnumTestEnumValues _tmp42_ = 0;
		GXmlGDocument* d5 = NULL;
		GXmlGDocument* _tmp43_ = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp44_ = NULL;
		GXmlGDocument* _tmp45_ = NULL;
		GXmlNode* _tmp46_ = NULL;
		GXmlNode* _tmp47_ = NULL;
		GXmlGDocument* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp0_ = serializable_property_enum_test_enumeration_values_new ();
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		e = _tmp0_;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp1_ = e;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp2_ = serializable_property_enum_test_enum_new ();
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp3_ = _tmp2_;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_values (_tmp1_, _tmp3_);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp3_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp4_ = e;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp5_ = serializable_property_enum_test_enumeration_values_get_values (_tmp4_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp6_ = _tmp5_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_value (_tmp6_, SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_AP, &_inner_error_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1475 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp7_ = gxml_gdocument_new ();
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		d1 = _tmp7_;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp8_ = e;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp9_ = d1;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp10_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp8_, (GXmlNode*) _tmp9_, &_inner_error_);
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp11_ = _tmp10_;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp11_);
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1498 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp12_ = d1;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp13_ = gxml_gnode_to_string ((GXmlGNode*) _tmp12_);
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp14_ = _tmp13_;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp15_ = g_strconcat ("XML1: ", _tmp14_, NULL);
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp16_ = _tmp15_;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp16_);
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp16_);
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp14_);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp17_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <Enum optionalvalues=\"SerExtension\"/>", 0, &_inner_error_);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		d2 = _tmp17_;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1527 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp18_ = e;
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp19_ = d2;
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp18_, (GXmlNode*) _tmp19_, &_inner_error_);
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1544 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp21_ = e;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp22_ = serializable_property_enum_test_enumeration_values_get_optional_values (_tmp21_);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp23_ = _tmp22_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp24_ = serializable_property_enum_test_enum_get_value (_tmp23_, &_inner_error_);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp20_ = _tmp24_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1565 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp20_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_EXTENSION, "e.optional_values.get_value () == Enum.Values.SER_EXTENSION");
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp25_ = gxml_gdocument_new ();
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		d3 = _tmp25_;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp26_ = e;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp27_ = d3;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp28_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp26_, (GXmlNode*) _tmp27_, &_inner_error_);
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp29_ = _tmp28_;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp29_);
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1594 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp30_ = d3;
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp31_ = gxml_gnode_to_string ((GXmlGNode*) _tmp30_);
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp32_ = _tmp31_;
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp33_ = g_strconcat ("XML2: ", _tmp32_, NULL);
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp34_ = _tmp33_;
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp34_);
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp34_);
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp32_);
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp35_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <Enum OPTIONALVALUES=\"SERTHREE\"/>", 0, &_inner_error_);
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		d4 = _tmp35_;
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1627 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp36_ = e;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp37_ = d4;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp36_, (GXmlNode*) _tmp37_, &_inner_error_);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d4);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1648 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp39_ = e;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp40_ = serializable_property_enum_test_enumeration_values_get_optional_values (_tmp39_);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp41_ = _tmp40_;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp42_ = serializable_property_enum_test_enum_get_value (_tmp41_, &_inner_error_);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp38_ = _tmp42_;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d4);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1673 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp38_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE, "e.optional_values.get_value () == Enum.Values.SER_THREE");
#line 164 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp43_ = gxml_gdocument_new ();
#line 164 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		d5 = _tmp43_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp44_ = e;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp45_ = d5;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp46_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp44_, (GXmlNode*) _tmp45_, &_inner_error_);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp47_ = _tmp46_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp47_);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d5);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d4);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1706 "SerializablePropertyEnumTest.c"
			goto __catch31_g_error;
		}
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp48_ = d5;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp49_ = gxml_gnode_to_string ((GXmlGNode*) _tmp48_);
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp50_ = _tmp49_;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp51_ = g_strconcat ("XML3: ", _tmp50_, NULL);
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp52_ = _tmp51_;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp52_);
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp52_);
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp50_);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d5);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d4);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d3);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d2);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d1);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_object_unref0 (e);
#line 1737 "SerializablePropertyEnumTest.c"
	}
	goto __finally31;
	__catch31_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp53_ = NULL;
		const gchar* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		e = _inner_error_;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_inner_error_ = NULL;
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp53_ = e->message;
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp54_ = string_to_string (_tmp53_);
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp55_ = g_strconcat ("ERROR: ", _tmp54_, NULL);
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_tmp56_ = _tmp55_;
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp56_);
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp56_);
#line 169 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_assert_not_reached ();
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		_g_error_free0 (e);
#line 1767 "SerializablePropertyEnumTest.c"
	}
	__finally31:
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_clear_error (&_inner_error_);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		return;
#line 1778 "SerializablePropertyEnumTest.c"
	}
}


static void ___lambda157__gtest_func (void) {
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	__lambda157_ ();
#line 1786 "SerializablePropertyEnumTest.c"
}


void serializable_property_enum_test_add_tests (void) {
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_test_add_func ("/gxml/serializable/Enum/basic", ___lambda154__gtest_func);
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_test_add_func ("/gxml/serializable/Enum/changes", ___lambda155__gtest_func);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_test_add_func ("/gxml/serializable/Enum/string", ___lambda156__gtest_func);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_test_add_func ("/gxml/serializable/Enum/property_name", ___lambda157__gtest_func);
#line 1799 "SerializablePropertyEnumTest.c"
}


SerializablePropertyEnumTest* serializable_property_enum_test_construct (GType object_type) {
	SerializablePropertyEnumTest* self = NULL;
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTest*) gxml_test_construct (object_type);
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return self;
#line 1809 "SerializablePropertyEnumTest.c"
}


SerializablePropertyEnumTest* serializable_property_enum_test_new (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return serializable_property_enum_test_construct (TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST);
#line 1816 "SerializablePropertyEnumTest.c"
}


GType serializable_property_enum_test_enum_values_get_type (void) {
	static volatile gsize serializable_property_enum_test_enum_values_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_enum_test_enum_values_type_id__volatile)) {
		static const GEnumValue values[] = {{SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE", "ser-one"}, {SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO", "ser-two"}, {SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE", "ser-three"}, {SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_AP, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_AP", "ap"}, {SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_EXTENSION, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_EXTENSION", "ser-extension"}, {0, NULL, NULL}};
		GType serializable_property_enum_test_enum_values_type_id;
		serializable_property_enum_test_enum_values_type_id = g_enum_register_static ("SerializablePropertyEnumTestEnumValues", values);
		g_once_init_leave (&serializable_property_enum_test_enum_values_type_id__volatile, serializable_property_enum_test_enum_values_type_id);
	}
	return serializable_property_enum_test_enum_values_type_id__volatile;
}


SerializablePropertyEnumTestEnumValues serializable_property_enum_test_enum_get_value (SerializablePropertyEnumTestEnum* self, GError** error) {
	SerializablePropertyEnumTestEnumValues result = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GError * _inner_error_ = NULL;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp1_ = gxml_serializable_enum_to_integer ((GXmlSerializableEnum*) self, &_inner_error_);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = _tmp1_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_propagate_error (error, _inner_error_);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		return 0;
#line 1849 "SerializablePropertyEnumTest.c"
	}
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	result = (SerializablePropertyEnumTestEnumValues) _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return result;
#line 1855 "SerializablePropertyEnumTest.c"
}


void serializable_property_enum_test_enum_set_value (SerializablePropertyEnumTestEnum* self, SerializablePropertyEnumTestEnumValues val, GError** error) {
	SerializablePropertyEnumTestEnumValues _tmp0_ = 0;
	GError * _inner_error_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = val;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	gxml_serializable_enum_parse_integer ((GXmlSerializableEnum*) self, (gint) _tmp0_, &_inner_error_);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_propagate_error (error, _inner_error_);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		return;
#line 1874 "SerializablePropertyEnumTest.c"
	}
}


void serializable_property_enum_test_enum_set_string (SerializablePropertyEnumTestEnum* self, const gchar* str, GError** error) {
	const gchar* _tmp0_ = NULL;
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = str;
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) self, _tmp0_);
#line 1887 "SerializablePropertyEnumTest.c"
}


SerializablePropertyEnumTestEnum* serializable_property_enum_test_enum_construct (GType object_type) {
	SerializablePropertyEnumTestEnum * self = NULL;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnum*) gxml_serializable_enum_construct (object_type);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return self;
#line 1897 "SerializablePropertyEnumTest.c"
}


SerializablePropertyEnumTestEnum* serializable_property_enum_test_enum_new (void) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return serializable_property_enum_test_enum_construct (SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM);
#line 1904 "SerializablePropertyEnumTest.c"
}


static GObject * serializable_property_enum_test_enum_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	SerializablePropertyEnumTestEnum * self;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	parent_class = G_OBJECT_CLASS (serializable_property_enum_test_enum_parent_class);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, SerializablePropertyEnumTestEnum);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	((GXmlSerializableEnum*) self)->_enumtype = SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_TYPE_VALUES;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return obj;
#line 1922 "SerializablePropertyEnumTest.c"
}


static void serializable_property_enum_test_enum_class_init (SerializablePropertyEnumTestEnumClass * klass) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	serializable_property_enum_test_enum_parent_class = g_type_class_peek_parent (klass);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (klass)->constructor = serializable_property_enum_test_enum_constructor;
#line 1931 "SerializablePropertyEnumTest.c"
}


static void serializable_property_enum_test_enum_instance_init (SerializablePropertyEnumTestEnum * self) {
}


GType serializable_property_enum_test_enum_get_type (void) {
	static volatile gsize serializable_property_enum_test_enum_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_enum_test_enum_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyEnumTestEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_enum_test_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyEnumTestEnum), 0, (GInstanceInitFunc) serializable_property_enum_test_enum_instance_init, NULL };
		GType serializable_property_enum_test_enum_type_id;
		serializable_property_enum_test_enum_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ENUM, "SerializablePropertyEnumTestEnum", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_enum_test_enum_type_id__volatile, serializable_property_enum_test_enum_type_id);
	}
	return serializable_property_enum_test_enum_type_id__volatile;
}


static gchar* serializable_property_enum_test_enumeration_values_real_node_name (GXmlSerializableObjectModel* base) {
	SerializablePropertyEnumTestEnumerationValues * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnumerationValues*) base;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = g_strdup ("Enum");
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return result;
#line 1963 "SerializablePropertyEnumTest.c"
}


static gchar* serializable_property_enum_test_enumeration_values_real_to_string (GXmlSerializableObjectModel* base) {
	SerializablePropertyEnumTestEnumerationValues * self;
	gchar* result = NULL;
	GType _tmp0_ = 0UL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 53 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnumerationValues*) base;
#line 53 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = G_TYPE_FROM_INSTANCE ((GObject*) self);
#line 53 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp1_ = g_type_name (_tmp0_);
#line 53 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 53 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	result = _tmp2_;
#line 53 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return result;
#line 1985 "SerializablePropertyEnumTest.c"
}


static gboolean serializable_property_enum_test_enumeration_values_real_property_use_nick (GXmlSerializableObjectModel* base) {
	SerializablePropertyEnumTestEnumerationValues * self;
	gboolean result = FALSE;
#line 54 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnumerationValues*) base;
#line 54 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	result = TRUE;
#line 54 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return result;
#line 1998 "SerializablePropertyEnumTest.c"
}


SerializablePropertyEnumTestEnumerationValues* serializable_property_enum_test_enumeration_values_construct (GType object_type) {
	SerializablePropertyEnumTestEnumerationValues * self = NULL;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnumerationValues*) gxml_serializable_object_model_construct (object_type);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return self;
#line 2008 "SerializablePropertyEnumTest.c"
}


SerializablePropertyEnumTestEnumerationValues* serializable_property_enum_test_enumeration_values_new (void) {
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return serializable_property_enum_test_enumeration_values_construct (SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES);
#line 2015 "SerializablePropertyEnumTest.c"
}


SerializablePropertyEnumTestEnum* serializable_property_enum_test_enumeration_values_get_values (SerializablePropertyEnumTestEnumerationValues* self) {
	SerializablePropertyEnumTestEnum* result;
	SerializablePropertyEnumTestEnum* _tmp0_ = NULL;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = self->priv->_values;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return result;
#line 2030 "SerializablePropertyEnumTest.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 2037 "SerializablePropertyEnumTest.c"
}


void serializable_property_enum_test_enumeration_values_set_values (SerializablePropertyEnumTestEnumerationValues* self, SerializablePropertyEnumTestEnum* value) {
	SerializablePropertyEnumTestEnum* _tmp0_ = NULL;
	SerializablePropertyEnumTestEnum* _tmp1_ = NULL;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = value;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_g_object_unref0 (self->priv->_values);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self->priv->_values = _tmp1_;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_object_notify ((GObject *) self, "values");
#line 2056 "SerializablePropertyEnumTest.c"
}


SerializablePropertyEnumTestEnum* serializable_property_enum_test_enumeration_values_get_optional_values (SerializablePropertyEnumTestEnumerationValues* self) {
	SerializablePropertyEnumTestEnum* result;
	SerializablePropertyEnumTestEnum* _tmp0_ = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = self->priv->_optional_values;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return result;
#line 2071 "SerializablePropertyEnumTest.c"
}


void serializable_property_enum_test_enumeration_values_set_optional_values (SerializablePropertyEnumTestEnumerationValues* self, SerializablePropertyEnumTestEnum* value) {
	SerializablePropertyEnumTestEnum* _tmp0_ = NULL;
	SerializablePropertyEnumTestEnum* _tmp1_ = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = value;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_g_object_unref0 (self->priv->_optional_values);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self->priv->_optional_values = _tmp1_;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_object_notify ((GObject *) self, "optional-values");
#line 2090 "SerializablePropertyEnumTest.c"
}


gint serializable_property_enum_test_enumeration_values_get_integer (SerializablePropertyEnumTestEnumerationValues* self) {
	gint result;
	gint _tmp0_ = 0;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = self->priv->_integer;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return result;
#line 2105 "SerializablePropertyEnumTest.c"
}


void serializable_property_enum_test_enumeration_values_set_integer (SerializablePropertyEnumTestEnumerationValues* self, gint value) {
	gint _tmp0_ = 0;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = value;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self->priv->_integer = _tmp0_;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_object_notify ((GObject *) self, "integer");
#line 2119 "SerializablePropertyEnumTest.c"
}


const gchar* serializable_property_enum_test_enumeration_values_get_name (SerializablePropertyEnumTestEnumerationValues* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = self->priv->_name;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	return result;
#line 2134 "SerializablePropertyEnumTest.c"
}


void serializable_property_enum_test_enumeration_values_set_name (SerializablePropertyEnumTestEnumerationValues* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp0_ = value;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_g_free0 (self->priv->_name);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self->priv->_name = _tmp1_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 2153 "SerializablePropertyEnumTest.c"
}


static void serializable_property_enum_test_enumeration_values_class_init (SerializablePropertyEnumTestEnumerationValuesClass * klass) {
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	serializable_property_enum_test_enumeration_values_parent_class = g_type_class_peek_parent (klass);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_type_class_add_private (klass, sizeof (SerializablePropertyEnumTestEnumerationValuesPrivate));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_property_enum_test_enumeration_values_real_node_name;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_property_enum_test_enumeration_values_real_to_string;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*)(GXmlSerializableObjectModel*)) serializable_property_enum_test_enumeration_values_real_property_use_nick;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_property_enum_test_enumeration_values_get_property;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_property_enum_test_enumeration_values_set_property;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_property_enum_test_enumeration_values_finalize;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES, g_param_spec_object ("values", "values", "values", SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES, g_param_spec_object ("optional-values", "OptionalValues", "Optional values", SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER, g_param_spec_int ("integer", "integer", "integer", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2182 "SerializablePropertyEnumTest.c"
}


static void serializable_property_enum_test_enumeration_values_instance_init (SerializablePropertyEnumTestEnumerationValues * self) {
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self->priv = SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_GET_PRIVATE (self);
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self->priv->_integer = 0;
#line 2191 "SerializablePropertyEnumTest.c"
}


static void serializable_property_enum_test_enumeration_values_finalize (GObject* obj) {
	SerializablePropertyEnumTestEnumerationValues * self;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValues);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_g_object_unref0 (self->priv->_values);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_g_object_unref0 (self->priv->_optional_values);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	_g_free0 (self->priv->_name);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (serializable_property_enum_test_enumeration_values_parent_class)->finalize (obj);
#line 2207 "SerializablePropertyEnumTest.c"
}


GType serializable_property_enum_test_enumeration_values_get_type (void) {
	static volatile gsize serializable_property_enum_test_enumeration_values_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_enum_test_enumeration_values_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyEnumTestEnumerationValuesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_enum_test_enumeration_values_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyEnumTestEnumerationValues), 0, (GInstanceInitFunc) serializable_property_enum_test_enumeration_values_instance_init, NULL };
		GType serializable_property_enum_test_enumeration_values_type_id;
		serializable_property_enum_test_enumeration_values_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializablePropertyEnumTestEnumerationValues", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_enum_test_enumeration_values_type_id__volatile, serializable_property_enum_test_enumeration_values_type_id);
	}
	return serializable_property_enum_test_enumeration_values_type_id__volatile;
}


static void _vala_serializable_property_enum_test_enumeration_values_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SerializablePropertyEnumTestEnumerationValues * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValues);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	switch (property_id) {
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_value_set_object (value, serializable_property_enum_test_enumeration_values_get_values (self));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_value_set_object (value, serializable_property_enum_test_enumeration_values_get_optional_values (self));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_value_set_int (value, serializable_property_enum_test_enumeration_values_get_integer (self));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		g_value_set_string (value, serializable_property_enum_test_enumeration_values_get_name (self));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 2252 "SerializablePropertyEnumTest.c"
		default:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 2258 "SerializablePropertyEnumTest.c"
	}
}


static void _vala_serializable_property_enum_test_enumeration_values_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SerializablePropertyEnumTestEnumerationValues * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValues);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	switch (property_id) {
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_values (self, g_value_get_object (value));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_optional_values (self, g_value_get_object (value));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_integer (self, g_value_get_int (value));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_name (self, g_value_get_string (value));
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 2292 "SerializablePropertyEnumTest.c"
		default:
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
		break;
#line 2298 "SerializablePropertyEnumTest.c"
	}
}


static void serializable_property_enum_test_class_init (SerializablePropertyEnumTestClass * klass) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyEnumTest.vala"
	serializable_property_enum_test_parent_class = g_type_class_peek_parent (klass);
#line 2306 "SerializablePropertyEnumTest.c"
}


static void serializable_property_enum_test_instance_init (SerializablePropertyEnumTest * self) {
}


/**
 *
 *  SerializablePropertyEnumTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType serializable_property_enum_test_get_type (void) {
	static volatile gsize serializable_property_enum_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_enum_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyEnumTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_enum_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyEnumTest), 0, (GInstanceInitFunc) serializable_property_enum_test_instance_init, NULL };
		GType serializable_property_enum_test_type_id;
		serializable_property_enum_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializablePropertyEnumTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_enum_test_type_id__volatile, serializable_property_enum_test_type_id);
	}
	return serializable_property_enum_test_type_id__volatile;
}



